( cd usr/lib/nautilus/extensions-1.0 ; rm -rf libtotem-properties-page.so.0 )
( cd usr/lib/nautilus/extensions-1.0 ; ln -sf libtotem-properties-page.so.0.0.0 libtotem-properties-page.so.0 )
( cd usr/lib/nautilus/extensions-1.0 ; rm -rf libtotem-properties-page.so )
( cd usr/lib/nautilus/extensions-1.0 ; ln -sf libtotem-properties-page.so.0.0.0 libtotem-properties-page.so )
( cd usr/lib ; rm -rf libtotem-plparser.so )
( cd usr/lib ; ln -sf libtotem-plparser.so.0.1.0 libtotem-plparser.so )
( cd usr/lib ; rm -rf libtotem-plparser.so.0 )
( cd usr/lib ; ln -sf libtotem-plparser.so.0.1.0 libtotem-plparser.so.0 )
( cd usr/share/doc/totem-1.2.0 ; rm -rf build )
( cd usr/share/doc/totem-1.2.0 ; ln -sf /usr/src/garnome-Ptgz-kit build )
#%% begin initialize totem-1.2.0-i386-P1
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications
fi
if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -q || exit 1
fi
GCONFTOOL=/usr/bin/gconftool-2
if [ ! -x $GCONFTOOL ]; then
  exit 1
fi
GCONF_CONFIG_SOURCE=`$GCONFTOOL --get-default-source`
export GCONF_CONFIG_SOURCE
GCONF_DIR=/usr/etc/gconf
SCHEMA_DIR=$GCONF_DIR/schemas
SCHEMA_FILES=" \
  totem-handlers.schemas \
  totem-video-thumbnail.schemas \
  totem.schemas \
  "
for s in $SCHEMA_FILES; do
  $GCONFTOOL --makefile-install-rule $SCHEMA_DIR/$s > /dev/null
done
#%% end
